@@ -7,8 +7,9 @@
 #'@param xtr The variables to be used in the transient term of the error correction model
 #'@return an lm object representing an error correction model
 #'@details
-#'The general format of an ECM is \deqn{\Delta y = \beta_{0} + \beta_{1}\Delta x_{1,t} +...+ \beta_{i}\Delta x_{i,t} + \gamma(y_{t-1} - (x1_{t-1} +...+ x_{i,t-1})).}
+#'The general format of an ECM is \deqn{\Delta y = \beta_{0} + \beta_{1}\Delta x_{1,t} +...+ \beta_{i}\Delta x_{i,t} + \gamma(y_{t-1} - (\alpha_{1}x_{1,t-1} +...+ \alpha_{i}x_{i,t-1})).}
 #'The ecm function here modifies the equation to the following: \deqn{\Delta y = \beta_{0} + \beta_{1}\Delta x_{1,t} +...+ \beta_{i}\Delta x_{i,t} + \gamma y_{t-1} + \gamma_{1}x_{1,t-1} +...+ \gamma_{i}x_{i,t-1},}
+#'\deqn{where \gamma_{i} = \gamma \alpha_{i},} 
 #'so it can be modeled as a simpler ordinary least squares (OLS) function using R's lm function.
 #'
 #'Notice that an ECM models the change in the target variable (y). This means that the predictors will be lagged and differenced,
@@ -38,48 +39,47 @@
 #'@export
 #'@importFrom stats lm
 ecm <- function (y, xeq, xtr) {
-  if(missing(xeq)){
-    if(class(xtr)!='data.frame'){
+  if (sum(grepl("^delta|Lag1$", names(xtr))) > 0 | sum(grepl("^delta", names(xeq))) > 0) {
+    warning("You have column name(s) in xeq or xtr that begin with 'delta' or end with 'Lag1'. It is strongly recommended that you change this, otherwise the function 'ecmpredict' will result in errors or incorrect predictions.")
+  }
+  
+  if (missing(xeq)) {
+    if (class(xtr) != "data.frame") {
       xtrnames <- deparse(substitute(xtr))
-      xtrnames <- substr(xtrnames, regexpr("\\$", xtrnames)+1, nchar(xtrnames))
-    } else{
+      xtrnames <- substr(xtrnames, regexpr("\\$", xtrnames) + 1, nchar(xtrnames))
+    } else {
       xtrnames <- names(xtr)
     }
-  } else{
+  } else {
     xeqnames <- names(xeq)
-    if(class(xeq)!='data.frame'){
+    if (class(xeq) != "data.frame") {
       xeqnames <- deparse(substitute(xeq))
-      xeqnames <- substr(xeqnames, regexpr("\\$", xeqnames)+1, nchar(xeqnames))
+      xeqnames <- substr(xeqnames, regexpr("\\$", xeqnames) + 1, nchar(xeqnames))
     }
-    if(missing(xtr)){
+    if (missing(xtr)) {
       xtrnames <- xeqnames
       xtr <- xeq
-    } else{
+    } else {
       xtrnames <- names(xtr)
     }
-
-    xeqnames <- paste0(xeqnames, 'Lag1')
+    xeqnames <- paste0(xeqnames, "Lag1")
     xeq <- as.data.frame(xeq)
-    ifelse(ncol(xeq)>1, xeq <- rbind(rep(NA, ncol(xeq)), xeq[1:(nrow(xeq)-1),]), xeq <- data.frame(c(NA, xeq[1:(nrow(xeq)-1),])))
+    ifelse(ncol(xeq) > 1, xeq <- rbind(rep(NA, ncol(xeq)), xeq[1:(nrow(xeq) - 1), ]), xeq <- data.frame(c(NA, xeq[1:(nrow(xeq) - 1), ])))
   }
-
-  xtrnames <- paste0('delta', xtrnames)
+  xtrnames <- paste0("delta", xtrnames)
   xtr <- as.data.frame(xtr)
   xtr <- data.frame(apply(xtr, 2, diff, 1))
-
   dy <- diff(y, 1)
-
-  if(!missing(xeq)){
-    yLag1 <- y[1:(length(y)-1)]
-    x <- cbind(xtr, xeq[complete.cases(xeq),])
+  if (!missing(xeq)) {
+    yLag1 <- y[1:(length(y) - 1)]
+    x <- cbind(xtr, xeq[complete.cases(xeq), ])
     x <- cbind(x, yLag1)
-    names(x) <- c(xtrnames, xeqnames, 'yLag1')
-  } else{
+    names(x) <- c(xtrnames, xeqnames, "yLag1")
+  } else {
     x <- xtr
     names(x) <- xtrnames
   }
-
-  ecm <- lm(dy~., data=x)
+  ecm <- lm(dy ~ ., data = x)
   return(ecm)
 }
 
